@@ -6,22 +6,25 @@ from urllib.parse import urlparse, urlunparse, urljoin
 import pytest
 from box import Box
 
-from framework.exit_code import ExitCode
 from framework.db.redis_db import RedisDB
 from framework.db.mysql_db import MysqlDB
 from framework.utils.log_util import logger
 from framework.render_data import RenderData
 from framework.http_client import ResponseUtil
-from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
+from framework.utils.date_util import DateUtil
 from framework.utils.common import snake_to_pascal, SingletonFaker
-from framework.global_attribute import CONFIG, GlobalAttribute, _FRAMEWORK_CONTEXT
-from framework.exceptions import ValidateException, RenderException, RequestException, ResponseException
+from framework.global_attribute import GlobalAttribute, _FRAMEWORK_CONTEXT,CONTEXT
+from framework.exceptions import ValidateException, RenderException, RequestException, ResponseException, \
+    GetAccountError, GetAppHttpError
 from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed
 
+from handlers.extend_base_test_case_attr import ExtendBaseTestCase
+from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
+
 module = importlib.import_module("test_case.conftest")
 
 
-class BaseTestCase(object):
+class BaseTestCase(ExtendBaseTestCase):
     http = None
     data: Box = None
     scenario: Box = None
@@ -32,17 +35,26 @@ class BaseTestCase(object):
     payment_type: PaymentType = PaymentType
     risk_level: RiskLevel = RiskLevel
     is_delayed: IsDelayed = IsDelayed
+    date_util: DateUtil = DateUtil
+    logger: logger = logger
     # faker方法文档 https://blog.csdn.net/m0_60052979/article/details/126368024
     faker = SingletonFaker(locale=FAKER_LANGUAGE).faker
+    env = CONTEXT.get("env")
 
-    def request(self, app=None, *, account, data, **kwargs):
+    def request(self, app=None, *, account, data, **kwargs) -> ResponseUtil:
         try:
             app = self.default_app(app)
-            app_http = getattr(self.http, app)
+            try:
+                app_http = getattr(self.http, app)
+            except AttributeError as e:
+                raise GetAppHttpError(e)
             domain = self.context.get(app).get("domain")
             data = RenderData(data).render()
             data.request.url = self.replace_domain(data.request.url, domain)
-            self.response = getattr(app_http, account).request(data=data, kwargs=kwargs)
+            try:
+                self.response = getattr(app_http, account).request(data=data, kwargs=kwargs)
+            except AttributeError as e:
+                raise GetAccountError(e)
             if self.response.status_code in UNAUTHORIZED_CODE:
                 _http = _FRAMEWORK_CONTEXT.get(key="_http")
                 setattr(_http, app, getattr(module, f"{snake_to_pascal(app)}Login")(app))
@@ -56,11 +68,21 @@ class BaseTestCase(object):
             traceback.print_exc()
             pytest.fail(str(e))
 
+        except GetAccountError as e:
+            logger.error(f"获取账号{account}异常: {e}")
+            traceback.print_exc()
+            pytest.fail(str(e))
+
+        except GetAppHttpError as e:
+            logger.error(f"获取{app} http对象异常: {e}")
+            traceback.print_exc()
+            pytest.fail(str(e))
+
         except RequestException as e:
             logger.error(f"请求异常: {e}")
             traceback.print_exc()
             pytest.fail(str(e))
-            
+
         except ResponseException as e:
             logger.error(f"响应异常: {e}")
             traceback.print_exc()
@@ -72,30 +94,29 @@ class BaseTestCase(object):
             pytest.fail(str(e))
 
         except Exception as e:
-            # logger.error(e)
+            logger.error(e)
             traceback.print_exc()
-            # pytest.exit(e)
-            return None
+            pytest.fail(str(e))
 
-    def post(self, app, account, url, data=None, json=None, **kwargs):
+    def post(self, app, account, url, data=None, json=None, **kwargs) -> ResponseUtil:
         domain = self.context.get(app).get("domain")
         request = {"url": urljoin(domain, url), "data": data, "json": json}
         request.update({"method": "post", "headers": {}, **kwargs})
         return self.request(app=app, account=account, data=Box({"request": request}))
 
-    def get(self, app, account, url, params=None, **kwargs):
+    def get(self, app, account, url, params=None, **kwargs) -> ResponseUtil:
         domain = self.context.get(app).get("domain")
         request = {"url": urljoin(domain, url), "params": params}
         request.update({"method": "get", "headers": {}, **kwargs})
         return self.request(app=app, account=account, data=Box({"request": request}))
 
-    def put(self, app, account, url, data=None, json=None, **kwargs):
+    def put(self, app, account, url, data=None, json=None, **kwargs) -> ResponseUtil:
         domain = self.context.get(app).get("domain")
         request = {"url": urljoin(domain, url), "data": data, "json": json}
         request.update({"method": "put", "headers": {}, **kwargs})
         return self.request(app=app, account=account, data=Box({"request": request}))
 
-    def delete(self, app, account, url, **kwargs):
+    def delete(self, app, account, url, **kwargs) -> ResponseUtil:
         domain = self.context.get(app).get("domain")
         request = {"url": urljoin(domain, url)}
         request.update({"method": "delete", "headers": {}, **kwargs})
@@ -105,15 +126,17 @@ class BaseTestCase(object):
         try:
             return _FRAMEWORK_CONTEXT.get(app=self.default_app(app), key="mysql").get(db)
         except AttributeError as e:
+            logger.error(f"获取mysql连接异常: {e} {self.default_app(app)} {app} {db} ")
             traceback.print_exc()
-            pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
+            # pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
 
     def redis_conn(self, db, index=0, app=None) -> RedisDB:
         try:
             return _FRAMEWORK_CONTEXT.get(app=self.default_app(app), key="redis").get(db)[index]
         except AttributeError as e:
+            logger.error(f"获取redis连接异常: {e}")
             traceback.print_exc()
-            pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
+            # pytest.exit(ExitCode.LOAD_DATABASE_INFO_ERROR)
 
     def context_set(self, key, value):
         self.context.set(app=self.belong_app, key=key, value=value)
