@@ -2,44 +2,36 @@ import os
 import re
 import sys
 import copy
+import time
 import threading
 import importlib
 import traceback
 from pathlib import Path
 from itertools import chain
-from itertools import groupby
 from urllib.parse import urljoin
 from collections import OrderedDict
 from datetime import datetime, timedelta
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 import json
-import dill
 import retry
 import allure
 import pytest
 from box import Box
 import simplejson as json
-from redis import RedisError
-from pymysql import MySQLError
-
 import config.settings as settings
 from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
 from framework.db.redis_db import RedisDB
 from framework.utils.log_util import logger
-# from framework.render_data import RenderData
-from framework.utils.yaml_util import YamlUtil
-from framework.exceptions import LoginException
+from framework.utils.yaml_util import CachedYamlLoader
+from framework.exceptions import MysqlDBError, RedisDBError
 from framework.global_attribute import CONTEXT, CONFIG, _FRAMEWORK_CONTEXT
 from framework.utils.common import snake_to_pascal, get_apps, convert_numbers_to_decimal
 
 all_app = get_apps()
-stop_event = threading.Event()  # 线程共享信号
 module = importlib.import_module("test_case.conftest")
-
-# 可以捕获的初始化异常类型
-EXCEPTIONS = (LoginException, MySQLError, RedisError)
+MARK_LIST = [item for sublist in settings.MARK_LIST.values() for item in sublist]
 
 
 @pytest.fixture(autouse=True)
@@ -82,75 +74,71 @@ class Http(object):
     ...
 
 
-def init_mysql(app):
+def init_mysql():
     """初始化 MySQL 连接池"""
-    mysqls = CONFIG.get(app=app, key="mysql")
-    return {item: MysqlDB(**mysqls[item]) for item in mysqls}
+    try:
+        mysql_config = CONFIG.get(app=all_app[0], key="mysql")
+        mysql_conns = {item: MysqlDB(**mysql_config[item]) for item in mysql_config}
+        for app in all_app:
+            _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysql_conns)
+    except Exception as e:
+        raise MysqlDBError(e)
 
 
-def init_redis(app):
+def init_redis():
     """初始化 Redis 连接池（16个db）"""
-    redis = CONFIG.get(app=app, key="redis")
-    return {
-        db: [RedisDB(**{**db_info, "db": i}) for i in range(16)]
-        for db, db_info in redis.items()
-    }
+    try:
+        redis_config = CONFIG.get(app=all_app[0], key="redis")
+        redis_conns = {
+            db: [RedisDB(**{**db_info, "db": i}) for i in range(16)]
+            for db, db_info in redis_config.items()
+        }
+        for app in all_app:
+            _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=redis_conns)
+    except Exception as e:
+        raise RedisDBError(e)
 
 
 def inner_login(app):
     """单个系统的登录和资源初始化"""
-    if stop_event.is_set():
-        return
 
-    try:
-        # 登录逻辑
-        login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
-        setattr(Http, app, login_cls(app))
-
-        # Token 过期时间写入上下文
-        token_expiry = CONTEXT.get(app).get("token_expiry")
-        if token_expiry:
-            expire_time = datetime.now() + timedelta(seconds=token_expiry)
-            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
-
-        # 初始化 MySQL
-        _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=init_mysql(app))
-
-        # 初始化 Redis
-        _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=init_redis(app))
-
-    except EXCEPTIONS as e:
-        stop_event.set()
-        logger.error(f"[{app}] 初始化失败: {type(e).__name__} - {e}")
-        traceback.print_exc()
-        raise  # 让外层 future.result() 能捕获
+    login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
+    setattr(Http, app, login_cls(app))
+    # Token 过期时间写入上下文
+    token_expiry = CONTEXT.get(app).get("token_expiry")
+    if token_expiry:
+        expire_time = datetime.now() + timedelta(seconds=token_expiry)
+        _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
 
 
 def login():
-    """并发登录所有系统，失败则退出 pytest"""
+    def safe_call(func, name):
+        try:
+            logger.info(f"初始化{name}连接...")
+            func()
+            logger.info(f"{name}连接初始化成功")
+        except (MysqlDBError, RedisDBError) as e:
+            logger.error(f"{name}连接初始化异常: {e}")
+
+    # 启动 MySQL 和 Redis 初始化线程
+    threads = [
+        threading.Thread(target=safe_call, args=(init_mysql, "MySQL")),
+        threading.Thread(target=safe_call, args=(init_redis, "Redis"))
+    ]
+
+    for t in threads:
+        t.start()
+    for t in threads:
+        t.join()
+
     logger.info("登录账号".center(80, "*"))
-    try:
-        with ThreadPoolExecutor(max_workers=len(all_app)) as executor:
-            futures = {executor.submit(inner_login, app): app for app in all_app}
-            for future in as_completed(futures):
-                if stop_event.is_set():
-                    break  # 已经有线程失败，跳过后续
-                try:
-                    future.result()  # 如果线程抛异常，这里会触发
-                except Exception:
-                    # 已在 inner_login 打印详细信息，这里只负责退出
-                    stop_event.set()
-                    break
+    with ThreadPoolExecutor(max_workers=len(all_app)) as executor:
+        futures = {executor.submit(inner_login, app): app for app in all_app}
+        for future in as_completed(futures):
+            future.result()
 
-        if stop_event.is_set():
-            pytest.exit(ExitCode.LOGIN_ERROR)
-
-        logger.info("登录完成".center(80, "*"))
-        return Http
-
-    except Exception:
-        pytest.exit(ExitCode.LOGIN_ERROR)
-        return None
+    logger.info("登录完成".center(80, "*"))
+    return Http
 
 
 def find_data_path_by_case(app, case_file_name):
@@ -160,47 +148,110 @@ def find_data_path_by_case(app, case_file_name):
     :param case_file_name:
     :return:
     """
-    for file_path in Path(os.path.join(settings.DATA_DIR, app)).rglob(f"{case_file_name}.y*"):
+    env = CONTEXT.get("env")
+    for file_path in Path(os.path.join(settings.DATA_DIR, env, app)).rglob(f"{case_file_name}.y*"):
         if file_path:
             return file_path
 
 
+def disable_field(scenario, data):
+    if not scenario:
+        return data
+
+    def _clean(obj):
+        if isinstance(obj, dict):
+            keys_to_delete = []
+            for k, v in obj.items():
+                if isinstance(v, (dict, list)):
+                    _clean(v)
+                elif isinstance(v, str):
+                    for ak, av in scenario.items():
+                        if av == "disable" and v == f"${{{ak}}}":
+                            keys_to_delete.append(k)
+                            break
+            # 统一删除，避免边遍历边删
+            for k in keys_to_delete:
+                del obj[k]
+
+        elif isinstance(obj, list):
+            for item in obj:
+                if isinstance(item, (dict, list)):
+                    _clean(item)
+
+    _clean(data)
+    return data
+
+
 def match_keyword(keyword_expr: str, target_str: str) -> bool:
     """
-      按规则匹配字符串：
-      - 空表达式：直接返回 True
-      - 单个关键词（可能带文件扩展名）：直接 in 判断
-      - 多个关键词：必须带运算符，按逻辑表达式计算
-      """
+    按规则匹配字符串：
+    - 空表达式：直接返回 True
+    - 单个关键词：直接 in 判断
+    - 多关键词：支持 and / or / not / 括号
+    """
     if not keyword_expr.strip():
         return True  # 空关键字，默认匹配所有
 
     keyword_expr = keyword_expr.strip().lower()
     target_str = target_str.lower()
 
-    # 提取所有词，保留点号（文件扩展名）
-    words = re.findall(r"[^\s]+", keyword_expr)
-
-    # 单关键词，直接 in 判断
+    # 单个关键词直接处理
+    words = re.findall(r"[^\s()]+", keyword_expr)  # 提取非括号非空格的词
     if len(words) == 1:
         return words[0] in target_str
 
-    # 多关键词，按逻辑表达式处理
-    # 匹配运算符 or not and，其余作为关键词
-    tokens = re.findall(r"and|or|not|[^\s]+", keyword_expr)
-    expr_list = []
+    # 带逻辑表达式
+    # tokens 保留括号，分离 and/or/not/关键词
+    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
 
+    expr_list = []
     for t in tokens:
-        if t in {"and", "or", "not"}:
+        if t in {"and", "or", "not", "(", ")"}:
             expr_list.append(t)
         else:
+            # 替换为 True/False
             expr_list.append(str(t in target_str))
 
     expr_str = " ".join(expr_list)
     try:
         return eval(expr_str)
     except Exception as e:
-        print(f"表达式解析错误: {e}")
+        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
+        return False
+
+
+def match_mark(keyword_expr: str, target_list: list[str]) -> bool:
+    """
+    按规则匹配目标列表：
+    - 空表达式：直接返回 True
+    - 单个关键词：精准匹配 target_list 中某个元素
+    - 多个关键词：支持 and/or/not/括号
+    """
+    if not keyword_expr.strip():
+        return True  # 空关键字，默认匹配所有
+
+    keyword_expr = keyword_expr.strip().lower()
+    target_list = [s.lower() for s in target_list]
+
+    def contains(word: str) -> bool:
+        """精准匹配：word 必须等于 target_list 的某个元素"""
+        return word in target_list
+
+    # tokens：保留括号，拆分 and/or/not/关键词
+    tokens = re.findall(r"\(|\)|and|or|not|[^\s()]+", keyword_expr)
+
+    expr_list = []
+    for t in tokens:
+        if t in {"and", "or", "not", "(", ")"}:
+            expr_list.append(t)
+        else:
+            expr_list.append(str(contains(t)))
+
+    expr_str = " ".join(expr_list)
+    try:
+        return eval(expr_str)
+    except Exception as e:
+        logger.error(f"表达式解析错误: {e}, 表达式: {expr_str}")
         return False
 
 
@@ -226,19 +277,53 @@ def pytest_configure(config):
     :param config:
     :return:
     """
-
     for app in all_app:
         # 将所有app对应环境的基础测试数据加到全局
         CONTEXT.set_from_yaml(f"config/{app}/context.yaml", CONTEXT.env, app)
         # 将所有app对应环境的中间件配置加到全局
-        CONFIG.set_from_yaml(f"config/{app}/config.yaml", CONTEXT.env, app)
+        CONFIG.set_from_yaml(f"config/config.yaml", CONTEXT.env, app)
 
     CONTEXT.set(key="all_app", value=all_app)
     sys.path.append(settings.CASES_DIR)
 
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app) or []
+    else:
+        handlers = [h for value in app_handlers.values() for h in value] or []
+    global_handlers = getattr(settings, "GLOBAL_START_HANDLER_CLASSES", [])
+    global_handlers.extend(handlers)
+    handlers = global_handlers
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            cls = getattr(importlib.import_module(module_path), class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
 
-def pytest_addoption(parser):
-    parser.addini(name="ignore_error_and_continue", help="是否忽略失败case,继续执行")
+
+def pytest_unconfigure(config):
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_FINISH_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app) or []
+    else:
+        handlers = [h for value in app_handlers.values() for h in value] or []
+    global_handlers = getattr(settings, "GLOBAL_FINISH_HANDLER_CLASSES", [])
+    handlers.extend(global_handlers)
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            cls = getattr(importlib.import_module(module_path), class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
 
 
 def pytest_generate_tests(metafunc):
@@ -247,20 +332,23 @@ def pytest_generate_tests(metafunc):
     :param metafunc:
     :return:
     """
-
-    keyword = metafunc.config.getoption("keyword")
-    markexpr = metafunc.config.getoption("markexpr")
-    keyword_flag = match_keyword(keyword, metafunc.definition.keywords.node.nodeid)
-    # 用例路径匹配不到关键词,跳过用例加载
-    if not keyword_flag and not markexpr:
+    keyword_expr = metafunc.config.getoption("keyword")
+    mark_expr = metafunc.config.getoption("markexpr")
+    node_id = metafunc.definition.keywords.node.nodeid
+    # 关键字标记
+    keyword_flag = match_keyword(keyword_expr, node_id)
+    # 如果只通过关键字过滤，没匹配上则直接返回
+    if not keyword_flag and not mark_expr:
         return
-    # print(metafunc.definition.keywords.node.nodeid)
-
     # 获取当前待执行用例的文件名
     module_name = metafunc.module.__name__.split('.')[-1]
     func_file_path = metafunc.module.__file__
     # 获取当前待执行用例的函数名
     func_name = metafunc.function.__name__
+    # UPDATE: 为了支持Setup和Teardown的分组
+    if func_name in ["test_setup", "test_teardown"]:
+        return
+
     # 获取测试用例所属app
     belong_app = Path(func_file_path).relative_to(settings.CASES_DIR).parts[0]
     # 获取当前用例对应的测试数据路径
@@ -269,19 +357,20 @@ def pytest_generate_tests(metafunc):
         logger.error(f"测试数据文件: {func_file_path} 不存在")
         traceback.print_exc()
         pytest.exit(ExitCode.CASE_YAML_NOT_EXIST)
+    # yml转json
+    test_data = CachedYamlLoader(data_path).load_yml()
 
-    # UPDATE: 为了支持Setup和Teardown的分组
-    if func_name in ["test_setup", "test_teardown"]:
-        return
-
-    test_data = YamlUtil(data_path).load_yml()
     # 测试用例公共数据
     case_common = test_data.get("case_common")
+    # 忽略的用例直接跳过
     if case_common.get("ignore"):
         return
-
-
-
+    # 获取mark标记
+    marks = case_common.get("marks", [])
+    if not set(m.lower() for m in marks).issubset(m.lower() for m in MARK_LIST):
+        logger.warning(f"{func_name} 使用非规范的用例标签:{marks}")
+        if settings.STRICT_MARKS:
+            return
 
     # 测试用例数据
     case_data = test_data.get(func_name) or dict()
@@ -299,42 +388,44 @@ def pytest_generate_tests(metafunc):
     case_data.setdefault("module", case_common.get("module"))
     case_data.setdefault("describe", case_common.get("describe"))
     case_data["_belong_app"] = belong_app
-
+    # 根据belong_app获取域名
     domain = CONTEXT.get(key="domain", app=belong_app)
     domain = domain if domain.startswith("http") else f"https://{domain}"
+    # 获取request中的url
     url = case_data.get("request").get("url")
-    method = case_data.get("request").get("method")
+    # 判断url是否存在
     if not url:
-        # UPDATE: 有的步骤不需要请求接口 比如 只校验数据库， 去掉下面的校验
-        if not case_common.get("url"):
-            logger.warning(f"{func_file_path} request中缺少必填字段: url", case_data)
-            # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
-        else:
-            url = case_common.get("url")
-            case_data["request"]["url"] = url if url.strip().startswith("${") else urljoin(domain, url)
+        # 获取case_common中url
+        case_common_url = case_common.get("url") or ""
+        case_data["request"]["url"] = case_common_url if case_common_url.strip().startswith("${") else urljoin(
+            domain, case_common_url)
+        # # 判断case_common是否有url, 如果没有url给与提示
+        # if not case_common_url:
+        #     logger.warning(f"{func_name} request中缺少必要字段: url")
 
     else:
         case_data["request"]["url"] = url if url.strip().startswith("${") else urljoin(domain, url)
-
+    # 获取method
+    method = case_data.get("request").get("method")
+    # 判断method是否存在
     if not method:
-        # UPDATE: 有的步骤不需要请求接口 比如 只校验数据库， 去掉下面的校验
-        if not case_common.get("method"):
-            logger.warning(f"{func_file_path} request中缺少必填字段: method", case_data)
-            # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
-        else:
-            case_data["request"]["method"] = case_common.get("method")
+        # 获取case_common中method
+        case_common_method = case_common.get("method", None)
+        case_data["request"]["method"] = case_common_method
+        # # 如果没有method给与提示
+        # if not case_common_method:
+        #     logger.warning(f"{func_name} request中缺少必要字段: method")
 
-    for key in ["title", "level"]:
-        if key not in case_data:
-            logger.warning(f"{func_file_path} 缺少必填字段: {key}", case_data)
-            # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
-
-    if case_data.get("mark"):
-        metafunc.function.marks = [case_data.get("mark"), case_data.get("level")]
-    else:
-        metafunc.function.marks = [case_data.get("level")]
+    # 获取用例title
+    title = case_data.get("title")
+    # 如果没有title给与提示
+    if not title:
+        logger.warning(f"{func_name} 缺少必要字段: title")
 
     scenarios = case_common.get("scenarios")
+    if settings.ONLY_SUPPORT_SCENARIO and not scenarios:
+        logger.error("当前仅支持使用scenario的方式执行用例")
+        pytest.exit(ExitCode.NONSUPPORT_RUN_MODE)
     case_data_list = list()
     if scenarios:
         ids = list()
@@ -343,31 +434,61 @@ def pytest_generate_tests(metafunc):
                 continue
             if func_name in item.get("scenario").get("exclude", list()):
                 continue
-            _mark = CONTEXT.get("mark")
-            if _mark and item.get("scenario").get("flag") != _mark:
-                continue
-            deep_copied_case_data = copy.deepcopy(case_data)
             scenario = item.get("scenario")
+            level = scenario.get("level", settings.DEFAULT_CASE_LEVEL).lower()
+            if level not in settings.CASE_LEVEL_LIST:
+                logger.warning(f"{func_name} 使用非规范的用例级别 {level}")
+                if settings.STRICT_MARKS:
+                    continue
+            case_data["level"] = level
+            new_marks = marks.copy()
+            new_marks.append(level)
+            # mark标记
+            mark_flag = match_mark(mark_expr, new_marks)
+            # 用例路径匹配不到关键词,或者标签匹配不到用例，跳过该用例加载
+            if not keyword_flag or not mark_flag:
+                continue
+
             try:
+                deep_copied_case_data = copy.deepcopy(case_data)
                 # 剔除标记disable的字段
                 deep_copied_case_data = disable_field(scenario.get("data"), deep_copied_case_data)
                 deep_copied_case_data["_scenario"] = item.get("scenario")
-                gloabl_ignore_failed = json.loads(metafunc.config.getini("ignore_error_and_continue"))
-                deep_copied_case_data["_ignore_failed"] = case_common.get("ignore_failed", gloabl_ignore_failed)
+                deep_copied_case_data["_marks"] = new_marks
+                deep_copied_case_data["_ignore_failed"] = case_common.get("ignore_failed",
+                                                                          settings.GLOBAL_IGNORE_FAILED)
                 case_data_list.append(deep_copied_case_data)
-                ids.append(f'{case_data.get("title")} - {scenario.get("describe", "")}#{index + 1}')
-            except KeyError as e:
+                ids.append(f'{case_data.get("title")} - {scenario.get("describe") or ""}#{index + 1}')
+                logger.info(f"{node_id}::{case_data.get('title')} - {scenario.get('describe') or ''}#{index + 1}")
+
+            except Exception as e:
                 logger.error(f"scenario参数化格式不正确:{e}")
                 traceback.print_exc()
-                pytest.exit(ExitCode.PARAMETRIZE_ATTRIBUTE_NOT_EXIT)
+                pytest.exit(ExitCode.SCENARIO_FORMAT_ERROR)
+
         metafunc.parametrize("data", case_data_list, ids=ids, scope="function")
     else:
         if not case_common.get("ignore"):
             case_data["_scenario"] = {"data": {}}
-            gloabl_ignore_failed = json.loads(metafunc.config.getini("ignore_error_and_continue"))
-            case_data["_ignore_failed"] = case_common.get("ignore_failed", gloabl_ignore_failed)
-            case_data_list = [case_data]
+            case_data["_ignore_failed"] = case_common.get("ignore_failed", settings.GLOBAL_IGNORE_FAILED)
+            level = case_data.get("level", settings.DEFAULT_CASE_LEVEL)
+            if level not in settings.CASE_LEVEL_LIST:
+                logger.warning(f"{func_name}使用非规范的用例级别 {level}")
+                if settings.STRICT_MARKS:
+                    return
+            case_data["level"] = level
+            new_marks = marks.copy()
+            new_marks.append(level)
+            # 用例加mark标签
+            case_data["_marks"] = new_marks
+            # mark标记
+            mark_flag = match_mark(mark_expr, new_marks)
+            # 用例路径匹配不到关键词,或者标签匹配不到用例，跳过该用例加载
+            if not keyword_flag or not mark_flag:
+                return
         # 进行参数化生成用例
+        logger.info(f"{node_id}::{case_data.get('title')}#1")
+        case_data_list = [case_data]
         metafunc.parametrize("data", case_data_list, ids=[f'{case_data.get("title")}#1'], scope="function")
 
 
@@ -376,43 +497,13 @@ def pytest_collection_modifyitems(items):
     new_items = sort(items)
     # Demo: new_items = [items[0],items[2],items[1],items[3]]
     items[:] = new_items
-
     for item in items:
-        try:
-            marks = item.function.marks
+        # 获取mark标记
+        data = item.callspec.params["data"]
+        if isinstance(data, dict):
+            marks = data.get("_marks")
             for mark in marks:
-                if isinstance(mark, list):
-                    for _ in mark:
-                        item.add_marker(_)
-                else:
-                    item.add_marker(mark)
-        except Exception:
-            pass
-
-
-def disable_field(scenario, data):
-    def _clean(obj):
-        if isinstance(obj, dict):
-            keys_to_delete = []
-            for k, v in obj.items():
-                if isinstance(v, (dict, list)):
-                    _clean(v)
-                elif isinstance(v, str):
-                    for ak, av in scenario.items():
-                        if av == "disable" and v == f"${{{ak}}}":
-                            keys_to_delete.append(k)
-                            break
-            # 统一删除，避免边遍历边删
-            for k in keys_to_delete:
-                del obj[k]
-
-        elif isinstance(obj, list):
-            for item in obj:
-                if isinstance(item, (dict, list)):
-                    _clean(item)
-
-    _clean(data)
-    return data
+                item.add_marker(mark)
 
 
 # UPDATE 将用例 按类名进行分组的核心方法
@@ -517,6 +608,9 @@ def sort(case_items):
 def pytest_collection_finish(session):
     """获取最终排序后的 items 列表"""
     # 过滤掉item名称是test_setup或test_teardown的
+    logger.info(f"共收集到 {len(session.items)} 个测试用例")
+    if len(session.items) == 0:
+        pytest.exit(0)
     session.items = [item for item in session.items if item.name not in ["test_setup", "test_teardown"]]
 
     # 1. 筛选出带井号 名称带'#' 的item，并记录原始索引
@@ -566,7 +660,7 @@ def pytest_runtest_setup(item):
         data = item.callspec.params.get("data")
         test_object.data = Box(data)
         test_object.scenario = Box(
-            json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario").get("data")))))
+            json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario")))))
         test_object.belong_app = data.get("_belong_app")
         test_before_scenario = getattr(test_object, "test_setup", None)
         if test_before_scenario:
@@ -592,19 +686,27 @@ def pytest_runtest_call(item):
         if item.funcargs.get("setup_success") is False:
             pytest.skip(f"test_setup execute error")
         # 判断上一个用例是否执行失败，如果上一个用例执行失败，则主动标记用例执行失败，不会执行用例（解决场景性用例，有一个失败则后续用例判为失败）
+
         index = item.session.items.index(item)
-        current_cls_name = item.nodeid.rsplit("::", 1)[0]  # 向前遍历，找到属于同一个类的用例
-        for prev_item in reversed(item.session.items[:index]):  # 只遍历当前 item 之前的
-            if current_cls_name == prev_item.nodeid.rsplit("::", 1)[0]:  # 确保是同一个类
-                status = getattr(prev_item, "status", None)  # 访问 status 属性
-                skip_reason = getattr(prev_item, "skip_reason", None)  # 访问 skip_reason 属性
-                if status == "skipped" and skip_reason.strip() in [
-                    "the previous method execute skipped",
-                    "the previous method execute failed",
-                    "test_setup execute error"]:
-                    pytest.skip("the previous method execute skipped")
-                elif status == "failed":
-                    pytest.skip("the previous method execute failed")
+        pattern = re.compile(r'^(?P<prefix>.*)::[^:\[\]]+\[.*#(?P<index>\d+)\]$')
+        current_match = pattern.match(item.nodeid)
+        current_cls_name = current_match.group('prefix')
+        current_index = current_match.group('index')
+        prev_item = item.session.items[index - 1]
+        prev_match = pattern.match(item.nodeid)
+        prev_cls_name = prev_match.group("prefix")
+        prev_index = prev_match.group("index")
+        # 确保是同一个类,并且索引相同
+        if current_cls_name == prev_cls_name and current_index == prev_index:
+            status = getattr(prev_item, "status", None)  # 访问 status 属性
+            skip_reason = getattr(prev_item, "skip_reason", None)  # 访问 skip_reason 属性
+            if status == "skipped" and skip_reason.strip() in [
+                "the previous method execute skipped",
+                "the previous method execute failed",
+                "test_setup execute error"]:
+                pytest.skip("the previous method execute skipped")
+            elif status == "failed":
+                pytest.skip("the previous method execute failed")
 
     # 获取原始测试数据
     origin_data = item.funcargs.get("data")
@@ -615,7 +717,7 @@ def pytest_runtest_call(item):
     http = item.funcargs.get("http")
     item.funcargs["data"] = item.instance.data = Box(origin_data)
     item.funcargs["scenario"] = item.instance.scenario = Box(
-        convert_numbers_to_decimal(origin_data.get("_scenario").get("data")))
+        convert_numbers_to_decimal(origin_data.get("_scenario")))
     _belong_app = origin_data.get("_belong_app")
     item.funcargs["belong_app"] = item.instance.belong_app = _belong_app
     item.funcargs["config"] = item.instance.config = CONFIG
@@ -623,13 +725,6 @@ def pytest_runtest_call(item):
     # 类式测试用例添加参数http，data, belong_app
     item.instance.http = http
 
-    # # 获取测试函数体内容
-    # func_source = re.sub(r'(?<!["\'])#.*', '', dill.source.getsource(item.function))
-    # # 校验测试用例中是否有断言
-    # if "assert" not in func_source:
-    #     logger.error(f"测试方法:{item.originalname}缺少断言")
-    #     pytest.exit(ExitCode.MISSING_ASSERTIONS)
-
     # 判断token是否过期，过期则重新登录
     expire_time = _FRAMEWORK_CONTEXT.get(app=_belong_app, key="expire_time")
     if expire_time:
@@ -640,12 +735,20 @@ def pytest_runtest_call(item):
             # 更新记录的过期时间
             token_expiry = CONTEXT.get(_belong_app).get("token_expiry")
             expire_time = datetime.now() + timedelta(seconds=token_expiry)
-            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+            _FRAMEWORK_CONTEXT.set(app=_belong_app, key="expire_time", value=expire_time)
 
 
 def pytest_runtest_teardown(item):
     if item.funcargs.get("last"):
         test_object = item.instance
+        test_object.context = CONTEXT
+        test_object.config = CONFIG
+        test_object.http = _FRAMEWORK_CONTEXT.get(key="_http")
+        data = item.callspec.params.get("data")
+        test_object.data = Box(data)
+        test_object.scenario = Box(
+            json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario")))))
+        test_object.belong_app = data.get("_belong_app")
         test_after_scenario = getattr(test_object, "test_teardown", None)
         if test_after_scenario:
             try:
@@ -695,6 +798,12 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     terminalreporter.write(f"跳过用例数: {skipped}\n", yellow=True, bold=True)
     terminalreporter.write(f"用例通过率: {pass_rate}%\n", green=True, bold=True)
     terminalreporter.write("====================================\n", blue=True, bold=True)
+    CONTEXT.set("summary", {
+        "passed": passed,
+        "failed": failed,
+        "skipped": skipped,
+        "total": total,
+    })
 
 
 def pytest_exception_interact(node, call, report):
@@ -707,59 +816,3 @@ def pytest_exception_interact(node, call, report):
     """
     if call.excinfo.type is AssertionError:
         logger.error(f"{node.nodeid} failed: {call.excinfo.value}\n")
-
-
-def pytest_sessionstart(session):
-    """
-    所有用例执行前，执行前置hanlder
-    :param session:
-    :return:
-    """
-
-    app = CONTEXT.get("app")
-    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
-    if app:
-        handlers = app_handlers.get(app)
-    else:
-        handlers = [h for value in app_handlers.values() for h in value]
-    global_handers = getattr(settings, "GLOBAL_START_HANDLER_CLASSES", [])
-    global_handers.extend(handlers)
-    handlers = global_handers
-    for handler in handlers:
-        try:
-            module_path, class_name = handler.rsplit(".", 1)
-            module = importlib.import_module(module_path)
-            cls = getattr(module, class_name)
-            cls().run()
-        except Exception as e:
-            logger.error(str(e))
-            traceback.print_exc()
-            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
-
-
-def pytest_sessionfinish(session, exitstatus):
-    """
-    所有用例执行完成后，执行后置hanlder
-
-    :param session:
-    :param exitstatus:
-    :return:
-    """
-    app = CONTEXT.get("app")
-    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
-    if app:
-        handlers = app_handlers.get(app)
-    else:
-        handlers = [h for value in app_handlers.values() for h in value]
-    global_handers = getattr(settings, "GLOBAL_FINISH_HANDLER_CLASSES", [])
-    handlers.extend(global_handers)
-    for handler in handlers:
-        try:
-            module_path, class_name = handler.rsplit(".", 1)
-            module = importlib.import_module(module_path)
-            cls = getattr(module, class_name)
-            cls().run()
-        except Exception as e:
-            logger.error(str(e))
-            traceback.print_exc()
-            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
