@@ -31,3 +31,12 @@ class MysqlDBError(Exception):
 class RedisDBError(Exception):
     """自定义 Redis 异常"""
     pass
+
+
+class GetAppHttpError(Exception):
+    """获取app http对象异常"""
+
+
+class GetAccountError(GetAppHttpError):
+    """获取账号异常"""
+    pass
