@@ -1,5 +1,6 @@
 import re
 from typing import List
+import urllib.parse
 from urllib.parse import urljoin
 
 import allure
@@ -22,14 +23,38 @@ from framework.exceptions import RequestException, ResponseException
 
 class ResponseUtil(object):
     def __init__(self, response: Response):
+        if not response.content:
+            raise ResponseException(response.text)
+
+        self.response = response
+        content_type = response.headers.get("Content-Type", "").lower()
+
         try:
-            self.response = response
-            if isinstance(self.response.json(), dict):
-                self.box = Box(built_json.loads(built_json.dumps(convert_numbers_to_decimal(self.response.json()))))
-            elif isinstance(self.response.json(), list):
-                self.box = BoxList(built_json.loads(built_json.dumps(convert_numbers_to_decimal(self.response.json()))))
+            # JSON 类型
+            if "application/json" in content_type:
+                data = self.response.json()
+                if isinstance(data, dict):
+                    self.box = Box(built_json.loads(built_json.dumps(convert_numbers_to_decimal(data))))
+                elif isinstance(data, list):
+                    self.box = BoxList(built_json.loads(built_json.dumps(convert_numbers_to_decimal(data))))
+                else:
+                    self.box = data
+
+            # 表单类型 (urlencoded)
+            elif "application/x-www-form-urlencoded" in content_type:
+                parsed = urllib.parse.parse_qs(self.response.text)
+                # parse_qs 返回 {key: [value]}，可以转成 dict
+                parsed = {k: v[0] if len(v) == 1 else v for k, v in parsed.items()}
+                self.box = Box(parsed)
+
+            # multipart/form-data，通常是文件流，直接返回原始内容
+            elif "multipart/form-data" in content_type:
+                self.box = self.response.content
+
+            # 其他类型（如文件下载）
             else:
-                self.box = self.response.text
+                self.box = self.response.content
+
         except Exception as e:
             raise ResponseException(f"{e}: {response.text}")
 
