@@ -11,12 +11,7 @@ from urllib.parse import unquote, quote, quote_plus, unquote_plus
 import pyotp
 import cn2an as c2a
 from faker import Faker
-from framework.settings import CONFIG_DIR
-
-try:
-    from utils.common import *
-except ImportError:
-    pass
+from config.settings import CONFIG_DIR
 
 
 class SingletonFaker(object):
